[dev] [PATCH] horde/lib/Auth/customsql.php broken

Roman Neuhauser neuhauser at bellavista.cz
Mon Sep 15 04:33:06 PDT 2003


horde/lib/Auth/customsql.php has been broken since it was introduced
into the tree: the driver is actually called Auth_sqlquery.

http://marc.theaimsgroup.com/?l=horde-dev&m=104206524901368&w=2
http://marc.theaimsgroup.com/?l=horde-dev&m=104689073718312&w=2

could someone please fix this? patch attached.

-- 
If you cc me or remove the list(s) completely I'll most likely ignore
your message.    see http://www.eyrie.org./~eagle/faqs/questions.html
-------------- next part --------------
Index: lib/Auth/customsql.php
===================================================================
RCS file: /repository/horde/lib/Auth/customsql.php,v
retrieving revision 1.4
diff -u -u -r1.4 customsql.php
--- lib/Auth/customsql.php	8 Sep 2003 23:47:25 -0000	1.4
+++ lib/Auth/customsql.php	15 Sep 2003 11:31:02 -0000
@@ -3,7 +3,7 @@
 require_once HORDE_BASE . '/lib/Auth/sql.php';
 
 /**
  * The Auth_sqlquery class provides a sql implementation of the Horde
  * authentication system with the possibility to set custom-made queries.
  * Only the "authenticate" capability is implemented for the moment.
  *
@@ -44,7 +44,7 @@
  * @since   Horde 1.3
  * @package horde.auth
  */
-class Auth_sqlquery extends Auth_sql {
+class Auth_customsql extends Auth_sql {
 
     /**
      * An array of capabilities, so that the driver can report which
@@ -65,7 +65,7 @@
      *
      * @param optional array $params  A hash containing connection parameters.
      */
-    function Auth_sqlquery($params = array())
+    function Auth_customsql($params = array())
     {
         $this->_params = $params;
 
@@ -3,7 +3,7 @@
 
 /**
- * The Auth_sqlquery class provides a sql implementation of the Horde
+ * The Auth_customsql class provides a sql implementation of the Horde
  * authentication system with the possibility to set custom-made queries.
  * Only the "authenticate" capability is implemented for the moment.


More information about the dev mailing list